<!-- oss buckets -->
<script id="services.oss.buckets.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">Location: <span id="oss.buckets.{{@key}}.location"><samp>{{value_or_none location}}</samp></span></div>
        <div class="list-group-item-text item-margin">Storage Class: <span id="oss.buckets.{{@key}}.storage_class"><samp>{{value_or_none storage_class}}</samp></span></div>
        <div class="list-group-item-text item-margin">Creation Date: <span id="oss.buckets.{{@key}}.creation_date"><samp>{{format_date creation_date}}</samp></span></div>
    </div>
</script>

<script>
    Handlebars.registerPartial("services.oss.buckets", $("#services\\.oss\\.buckets\\.partial").html());
</script>

<!-- Single oss bucket template -->
<script id="single_oss_bucket-template" type="text/x-handlebars-template">
    {{> modal-template template='services.oss.buckets'}}
</script>
<script>
    var single_oss_bucket_template = Handlebars.compile($("#single_oss_bucket-template").html());
</script>

